pitchtools.IntervalObjectSet
============================

.. inheritance-diagram:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.copy

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.intersection

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.isdisjoint

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.issubset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.issuperset

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.symmetric_difference

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.union

    Inherited from :py:class:`__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__and__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__cmp__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__contains__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__eq__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ge__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__gt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__hash__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__iter__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__le__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__len__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__lt__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ne__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__or__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rand__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__repr__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__ror__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rsub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__rxor__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__sub__

    Inherited from :py:class:`__builtin__.frozenset`

.. automethod:: abjad.tools.pitchtools.IntervalObjectSet.IntervalObjectSet.IntervalObjectSet.__xor__

    Inherited from :py:class:`__builtin__.frozenset`
